@@ -1,6 +1,6 @@
 /*
  * MONA
- * Copyright (C) 1997-2002 BRICS.
+ * Copyright (C) 1997-2004 BRICS.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,13 +34,14 @@ void
 Pos::printsource()
 {
   char *str;
-  int t, c;
+  int c;
+  size_t t;
   char temp[77];
 
   if (line == -1)
     return;
 
-  for (t = 0; t < (int) fileNames.size(); t++)
+  for (t = 0; t < fileNames.size(); t++)
     if (fileName == fileNames.get(t))
       break;
   cout << " '" << fileName << "' line " << line << " column " << col << "\n"; 
@@ -66,10 +67,12 @@ Pos::printsource()
   else
     strcpy(temp, str);
   cout << "  " << temp << "\n  ";
-  for (t = 1; t < c; t++)
-    if (temp[t] == '\t')
-      cout << "\t";
-    else
-      cout << " ";
-  cout << "^";
+  if (c < 77) {
+    for (t = 1; t < (size_t)c; t++)
+      if (t < strlen(temp) && temp[t] == '\t')
+        cout << "\t";
+      else
+        cout << " ";
+    cout << "^";
+  } 
 }
