@@ -1,6 +1,6 @@
 /*
  * MONA
- * Copyright (C) 1997-2002 BRICS.
+ * Copyright (C) 1997-2004 BRICS.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,25 +37,25 @@ static int phase = 0;
 void 
 VarCode::reduceAll(Deque<VarCode> *vcl) 
 {
- unmark();
-
- phase = 1; 
- reduce();
- for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
-   (*i).reduce();
- unmark();
- for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
-   (*i).unmark();
- codeTable->clearSCTable();
-
+  unmark();
+  
+  phase = 1; 
+  reduce();
+  for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
+    (*i).reduce();
+  unmark();
+  for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
+    (*i).unmark();
+  codeTable->clearSCTable();
+  
 #ifdef ENABLE_AND
- phase = 2; 
- reduce();
- for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
-   (*i).reduce();
- unmark();
- for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
-   (*i).unmark();
+  phase = 2; 
+  reduce();
+  for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
+    (*i).reduce();
+  unmark();
+  for (Deque<VarCode>::iterator i = vcl->begin(); i != vcl->end(); i++)
+    (*i).unmark();
 #endif
 }
 
@@ -314,7 +314,7 @@ Code_Negate::reduce1()
   if (vc.code->kind == cNegate) {
     Code_Negate *c = (Code_Negate *) vc.code;
     c->vc.code->refs++;
-    forwarded = VarCode(vc.vars->copy(), c->vc.code);
+    forwarded = VarCode(subst(c->vc.vars, &c->vars, vc.vars), c->vc.code); // NEW: fixed subst bug
   }
   // ~true --> false
   else if (vc.code->kind == cTrue)
@@ -322,7 +322,7 @@ Code_Negate::reduce1()
   // ~false --> true
   else if (vc.code->kind == cFalse)
     forwarded = codeTable->insert(new Code_True(pos));
-  if (forwarded.code)
+  if (forwarded.code) 
     codeTable->red_other++;
 #endif
 }
@@ -380,7 +380,7 @@ Code_And::reduce1()
     vc1.code->refs++;
     forwarded = VarCode(vc1.vars->copy(), vc1.code);
   }
-  if (forwarded.code)
+  if (forwarded.code) 
     codeTable->red_prod++;
 #endif
 }
@@ -417,7 +417,7 @@ Code_Or::reduce1()
     vc1.code->refs++;
     forwarded = VarCode(vc1.vars->copy(), vc1.code);
   }
-  if (forwarded.code)
+  if (forwarded.code) 
     codeTable->red_prod++;
 #endif
 }
@@ -449,7 +449,7 @@ Code_Impl::reduce1()
   else if (vc1.code == vc2.code && 
 	   equal(vc1.vars, vc2.vars))
     forwarded = codeTable->insert(new Code_True(pos));
-  if (forwarded.code)
+  if (forwarded.code) 
     codeTable->red_prod++;
 #endif
 }
@@ -486,7 +486,7 @@ Code_Biimpl::reduce1()
   else if (vc1.code == vc2.code && 
 	   equal(vc1.vars, vc2.vars))
     forwarded = codeTable->insert(new Code_True(pos));
-  if (forwarded.code)
+  if (forwarded.code) 
     codeTable->red_prod++;
 #endif
 }
