@@ -33,18 +33,18 @@ typedef struct {
   char path[MAX_VARIABLES+1];
 } Path;
 
-GTA *gta;
-unsigned numExceptions, nextException, exp;
-Path exception[MAX_EXCEPTION];
-State left, right; /* current left and right state */
-State defState;
-SsId s; /* current state space */
-unsigned sortedIndex[MAX_VARIABLES];
-int *offs;
-unsigned numOffs;
-char sortedPath[MAX_VARIABLES]; /* current exception path, sorted according to offsets */
-bdd_ptr bddPath[MAX_EXCEPTION];
-bdd_ptr def;
+static GTA *gta;
+static unsigned numExceptions, nextException, exp;
+static Path exception[MAX_EXCEPTION];
+static State left, right; /* current left and right state */
+static State defState;
+static SsId s; /* current state space */
+static unsigned sortedIndex[MAX_VARIABLES];
+static int *offs;
+static unsigned numOffs;
+static char sortedPath[MAX_VARIABLES]; /* current exception path, sorted according to offsets */
+static bdd_ptr bddPath[MAX_EXCEPTION];
+static bdd_ptr def;
 
 /*  USAGE:
  *
