@@ -1,3 +1,9 @@
+#ifdef USE_MALLOC
+
+int dl_dummy;
+
+#else
+
 #include "dlmalloc.h"
 
 /* 
@@ -2332,4 +2338,4 @@ History:
 
 */
 
-
+#endif
