@@ -1,6 +1,6 @@
 /*
  * MONA
- * Copyright (C) 1997-2000 BRICS.
+ * Copyright (C) 1997-2002 BRICS.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,15 +22,20 @@
 #define __MEM_h
 
 #include <stdlib.h>
+#include "gnuc.h"
 
 extern int memlimit;
 
+#ifdef MAXALLOCATED
+extern int maxallocated;
+#endif
+
 void mem_error();
 void *mem_alloc(size_t);
 void mem_free(void *);
 void *mem_resize(void *, size_t);
 void mem_copy(void *, void *, size_t);
 void mem_zero(void *, size_t);
-int mem_allocated();
+unsigned int mem_allocated();
 
 #endif
